@@ -19,6 +19,7 @@ import argparse
 import calendar
 import datetime
 import os
+import sys
 import time
 from pprint import pformat
 
@@ -54,6 +55,31 @@ def valid_date(date_string):
     return valid
 
 
+def valid_currency(currency):
+    """Validate the currency passed in."""
+    valid_currencies = [
+        "aud",
+        "cad",
+        "chf",
+        "cny",
+        "dkk",
+        "eur",
+        "gbp",
+        "hkd",
+        "jpy",
+        "nok",
+        "nzd",
+        "sek",
+        "sgd",
+        "usd",
+        "zar",
+    ]
+    if currency.lower() in valid_currencies:
+        return currency.upper()
+    msg = f"{currency} is an unsupported currency code."
+    raise argparse.ArgumentTypeError(msg)
+
+
 def today():
     """Create the date of today."""
     return datetime.datetime.now().replace(microsecond=0, second=0, minute=0)
@@ -242,7 +268,14 @@ def create_parser():
     yaml_parser = subparsers.add_parser("yaml", help="Generate a yaml for creating cost usage reports.")
 
     add_yaml_parser_args(yaml_parser)
-
+    report_parser.add_argument(
+        "-c",
+        "--currency",
+        dest="currency",
+        required=False,
+        type=valid_currency,
+        help="Sets the currency code on the reports, this will also override any currency in static ymls",
+    )
     parent_parser = argparse.ArgumentParser()
     parent_parser.add_argument(
         "-s",
@@ -518,11 +551,17 @@ def _load_static_report_data(options):
     """Validate/load and set start_date if static file is provided."""
     if not options.get("static_report_file"):
         return
+
+    static_file = options.get("static_report_file")
+    if not os.path.exists(static_file):
+        LOG.error(f"file does not exist: '{static_file}'")
+        sys.exit()
+
     LOG.info("Loading static data...")
     aws_tags = set()
     start_dates = []
     end_dates = []
-    static_report_data = load_yaml(options.get("static_report_file"))
+    static_report_data = load_yaml(static_file)
     for generator_dict in static_report_data.get("generators"):
         for _, attributes in generator_dict.items():
             start_date = get_start_date(attributes, options)
